import config from '../../mikro-orm.config'
import { MikroORM } from '@mikro-orm/mariadb'
import { appLogger } from '#utilities/logger'

/**
 * Singleton class for initializing and managing the database connection
 */
export class Database {
  private static instance: MikroORM | undefined

  private static async init(): Promise<MikroORM> {
    try {
      const orm = await MikroORM.init(config)
      appLogger.info('MikroORM connected successfully')
      return orm
    } catch (error) {
      appLogger.error(`MikroORM connection failed: ${error}`)
      throw error
    }
  }

  public static async getInstance(): Promise<MikroORM> {
    if (!Database.instance) {
      Database.instance = await Database.init()
    }
    return Database.instance
  }

  public static async close() {
    if (Database.instance) {
      await Database.instance.close()
      Database.instance = undefined
    }
  }
}